==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/az.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Lightbox Gallary parametrləri idarə");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Qalereya idarə");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Eni");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Boy");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image Eni");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Boy");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Thumb Aspect nisbəti Qoruğu");
define('MANAGE_GALLERY_SHOW_TITLES', "Show adları");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Image sil");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sifariş Sort edin");
define('MANAGE_GALLERY_PUBLISH_MSG', "dərc &#39;Update &quot;düyməsini basın <br /> Silindi images.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Bütün şəkillər boyutlandırılır edilmiş və parametrləri qeyd edilmişdir.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "bir səhv images boyutlandırma və ya ayarları qənaət var idi.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Sizin image (s) qəbul edilmişdir.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "image (s) yüklemek bir səhv var idi.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Siz yüklemek üçün çalışırıq fayl bir resim deyil.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Siz yüklemek üçün çalışırıq fayl çox böyükdür.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "title qeyd edildi.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Siz image silmək istəyirsiniz");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "image silinmişdir.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "image silinməsi səhv var idi.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parametrləri qənaət və images boyutlandırma, xahiş edirik gözləyin ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Yüklənir, xahiş edirik gözləyin ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "sort order qeyd olunmayıb. Siz sort sifariş saxlamaq istəyirsiniz?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "image sort order qeyd edildi.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "image növ qənaət bir səhv var idi.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/az.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Lightbox Gallary parametrləri idarə");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Qalereya idarə");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Eni");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Boy");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image Eni");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Boy");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Thumb Aspect nisbəti Qoruğu");
define('MANAGE_GALLERY_SHOW_TITLES', "Show adları");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Image sil");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sifariş Sort edin");
define('MANAGE_GALLERY_PUBLISH_MSG', "dərc &#39;Update &quot;düyməsini basın <br /> Silindi images.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Bütün şəkillər boyutlandırılır edilmiş və parametrləri qeyd edilmişdir.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "bir səhv images boyutlandırma və ya ayarları qənaət var idi.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Sizin image (s) qəbul edilmişdir.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "image (s) yüklemek bir səhv var idi.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Siz yüklemek üçün çalışırıq fayl bir resim deyil.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Siz yüklemek üçün çalışırıq fayl çox böyükdür.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "title qeyd edildi.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Siz image silmək istəyirsiniz");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "image silinmişdir.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "image silinməsi səhv var idi.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parametrləri qənaət və images boyutlandırma, xahiş edirik gözləyin ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Yüklənir, xahiş edirik gözləyin ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "sort order qeyd olunmayıb. Siz sort sifariş saxlamaq istəyirsiniz?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "image sort order qeyd edildi.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "image növ qənaət bir səhv var idi.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Yükləməyə çalışdığınız fayl &#39;upload_max_filesize&#39; və ya &#39;post_max_size&#39; PHP parametrlərindən daha böyükdür. Bu hədləri artırmaq üçün sistem idarəçinizlə əlaqə saxlayın.");
?>
